//%2006////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation, The Open Group.
// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; Symantec Corporation; The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//==============================================================================
//
//%/////////////////////////////////////////////////////////////////////////////

#ifndef Pegasus_CimToWsmResponseMapper_h
#define Pegasus_CimToWsmResponseMapper_h

#include <Pegasus/Common/CIMMessage.h>
#include <Pegasus/WsmServer/WsmResponse.h>
#include <Pegasus/WsmServer/WsmRequest.h>

PEGASUS_NAMESPACE_BEGIN

/**
    Converts CIMResponseMessage messages to WsmResponses.
*/
class PEGASUS_WSMSERVER_LINKAGE CimToWsmResponseMapper
{
public:

    CimToWsmResponseMapper();
    ~CimToWsmResponseMapper();

    WsmResponse* mapToWsmResponse(
        const WsmRequest* wsmRequest,
        const CIMResponseMessage* message);
    WsmFault mapCimExceptionToWsmFault(const CIMException& cimException);

    void convertCimToWsmInstance(
        const CIMInstance& cimInstance,
        WsmInstance& wsmInstance);
    void convertCimToWsmValue(
        const CIMValue& cimValue,
        WsmValue& wsmValue);
    void convertObjPathToEPR(
        const CIMObjectPath& objPath,
        WsmEndpointReference& epr);
    void convertCimToWsmDatetime(const CIMDateTime& cimDT, String& wsmDT);

private:

    WsmGetResponse* _mapToWsmGetResponse(
        const WsmGetRequest* wsmRequest,
        const CIMGetInstanceResponseMessage* response);
    WsmPutResponse* _mapToWsmPutResponse(
        const WsmPutRequest* wsmRequest,
        const CIMModifyInstanceResponseMessage* response);
    WsmCreateResponse* _mapToWsmCreateResponse(
        const WsmCreateRequest* wsmRequest,
        const CIMCreateInstanceResponseMessage* response);
    WsmDeleteResponse* _mapToWsmDeleteResponse(
        const WsmDeleteRequest* wsmRequest,
        const CIMDeleteInstanceResponseMessage* response);
    WsmFaultResponse* _mapToWsmFaultResponse(
        const WsmRequest* wsmRequest,
        const CIMResponseMessage* message);

    ContentLanguageList _getContentLanguages(const OperationContext& context)
    {
        if (context.contains(ContentLanguageListContainer::NAME))
        {
            return ((ContentLanguageListContainer)
                context.get(ContentLanguageListContainer::NAME)).getLanguages();
        }

        return ContentLanguageList();
    }
};

PEGASUS_NAMESPACE_END

#endif /* Pegasus_CimToWsmResponseMapper_h */
